@@ -3,4 +3,4 @@
 additional and slitly imporved thread"""
 from jpe_types.paralel.thread import Thread, LockableThread, threadInharitanceFilter
 
-__all__ = ["Thread", "LockableThread", "threadInharitanceFilter"]
\ No newline at end of file
+#__all__ = ["Thread", "LockableThread", "threadInharitanceFilter"]
\ No newline at end of file
